==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ParameterBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ParameterBuilder extends io.fabric8.openshift.api.model.ParameterFluentImpl<io.fabric8.openshift.api.model.ParameterBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Parameter,io.fabric8.openshift.api.model.ParameterBuilder>{
  public ParameterBuilder() {
    this(false);
  }
  public ParameterBuilder(java.lang.Boolean validationEnabled) {
    this(new Parameter(), validationEnabled);
  }
  public ParameterBuilder(io.fabric8.openshift.api.model.ParameterFluent<?> fluent) {
    this(fluent, false);
  }
  public ParameterBuilder(io.fabric8.openshift.api.model.ParameterFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Parameter(), validationEnabled);
  }
  public ParameterBuilder(io.fabric8.openshift.api.model.ParameterFluent<?> fluent,io.fabric8.openshift.api.model.Parameter instance) {
    this(fluent, instance, false);
  }
  public ParameterBuilder(io.fabric8.openshift.api.model.ParameterFluent<?> fluent,io.fabric8.openshift.api.model.Parameter instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withGenerate(instance.getGenerate()); 
    fluent.withName(instance.getName()); 
    fluent.withRequired(instance.getRequired()); 
    fluent.withValue(instance.getValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ParameterBuilder(io.fabric8.openshift.api.model.Parameter instance) {
    this(instance,false);
  }
  public ParameterBuilder(io.fabric8.openshift.api.model.Parameter instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withFrom(instance.getFrom()); 
    this.withGenerate(instance.getGenerate()); 
    this.withName(instance.getName()); 
    this.withRequired(instance.getRequired()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ParameterFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Parameter build() {
    Parameter buildable = new Parameter(fluent.getDescription(),fluent.getDisplayName(),fluent.getFrom(),fluent.getGenerate(),fluent.getName(),fluent.getRequired(),fluent.getValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParameterBuilder that = (ParameterBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.2.0-sources.jar: io/fabric8/openshift/api/model/ParameterBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ParameterBuilder extends ParameterFluentImpl<ParameterBuilder> implements VisitableBuilder<Parameter,ParameterBuilder>{
  public ParameterBuilder() {
    this(false);
  }
  public ParameterBuilder(Boolean validationEnabled) {
    this(new Parameter(), validationEnabled);
  }
  public ParameterBuilder(ParameterFluent<?> fluent) {
    this(fluent, false);
  }
  public ParameterBuilder(ParameterFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Parameter(), validationEnabled);
  }
  public ParameterBuilder(ParameterFluent<?> fluent,Parameter instance) {
    this(fluent, instance, false);
  }
  public ParameterBuilder(ParameterFluent<?> fluent,Parameter instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withGenerate(instance.getGenerate()); 
    fluent.withName(instance.getName()); 
    fluent.withRequired(instance.getRequired()); 
    fluent.withValue(instance.getValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ParameterBuilder(Parameter instance) {
    this(instance,false);
  }
  public ParameterBuilder(Parameter instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withFrom(instance.getFrom()); 
    this.withGenerate(instance.getGenerate()); 
    this.withName(instance.getName()); 
    this.withRequired(instance.getRequired()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ParameterFluent<?> fluent;
  Boolean validationEnabled;
  public Parameter build() {
    Parameter buildable = new Parameter(fluent.getDescription(),fluent.getDisplayName(),fluent.getFrom(),fluent.getGenerate(),fluent.getName(),fluent.getRequired(),fluent.getValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
